# This file was auto-generated by Fern from our API Definition.

import typing

from .date_definition_with_includes import DateDefinitionWithIncludes
from .long_text_definition_with_includes import LongTextDefinitionWithIncludes
from .number_definition_with_includes import NumberDefinitionWithIncludes
from .rating_definition_with_includes import RatingDefinitionWithIncludes
from .select_definition_with_includes import SelectDefinitionWithIncludes
from .select_multi_definition_with_includes import SelectMultiDefinitionWithIncludes
from .text_definition_with_includes import TextDefinitionWithIncludes
from .toggle_definition_with_includes import ToggleDefinitionWithIncludes
from .user_multi_definition_with_includes import UserMultiDefinitionWithIncludes
from .user_single_definition_with_includes import UserSingleDefinitionWithIncludes

FieldDefinitionWithIncludes = typing.Union[
    DateDefinitionWithIncludes,
    LongTextDefinitionWithIncludes,
    NumberDefinitionWithIncludes,
    RatingDefinitionWithIncludes,
    SelectDefinitionWithIncludes,
    SelectMultiDefinitionWithIncludes,
    TextDefinitionWithIncludes,
    ToggleDefinitionWithIncludes,
    UserMultiDefinitionWithIncludes,
    UserSingleDefinitionWithIncludes,
]
