# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .user_multi_definition_field_configuration_custom_members_item_type import (
    UserMultiDefinitionFieldConfigurationCustomMembersItemType,
)


class UserMultiDefinitionFieldConfigurationCustomMembersItem(UniversalBaseModel):
    id: str = pydantic.Field()
    """
    User Id
    """

    type: UserMultiDefinitionFieldConfigurationCustomMembersItemType

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
