# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .user_multi_definition_params_field_configuration import UserMultiDefinitionParamsFieldConfiguration


class UserMultiDefinitionParams(UniversalBaseModel):
    field_configuration: UserMultiDefinitionParamsFieldConfiguration
    field_type: typing.Literal["user_multi"] = "user_multi"
    name: str = pydantic.Field()
    """
    Field definition name
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
