# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import UniversalBaseModel


class FileImportParamsData(UniversalBaseModel):
    key: str = pydantic.Field()
    """
    File key/path within the filespace
    """

    name: str = pydantic.Field()
    """
    File name
    """

    storage_location: str = pydantic.Field()
    """
    Storage location with account UUID as the value or prefix. Applies to accounts with Storage Connect
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
