# This file was auto-generated by Fern from our API Definition.

import typing

from .date_definition import DateDefinition
from .long_text_definition import LongTextDefinition
from .number_definition import NumberDefinition
from .rating_definition import RatingDefinition
from .select_definition import SelectDefinition
from .select_multi_definition import SelectMultiDefinition
from .text_definition import TextDefinition
from .toggle_definition import ToggleDefinition
from .user_multi_definition import UserMultiDefinition
from .user_single_definition import UserSingleDefinition

FieldDefinition = typing.Union[
    DateDefinition,
    LongTextDefinition,
    NumberDefinition,
    RatingDefinition,
    SelectDefinition,
    SelectMultiDefinition,
    TextDefinition,
    ToggleDefinition,
    UserMultiDefinition,
    UserSingleDefinition,
]
