# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .update_select_definition_params_field_configuration import UpdateSelectDefinitionParamsFieldConfiguration


class UpdateSelectDefinitionParams(UniversalBaseModel):
    field_configuration: typing.Optional[UpdateSelectDefinitionParamsFieldConfiguration] = None
    field_type: typing.Literal["select"] = "select"
    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Field definition name
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
