# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class AttachmentInput(UniversalBaseModel):
    """
    Input for creating a comment attachment
    """

    file_size: int = pydantic.Field()
    """
    Attachment file size in bytes (up to 5TB)
    """

    media_type: str = pydantic.Field()
    """
    File media type
    """

    name: str = pydantic.Field()
    """
    Filename
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
