# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class CommentAttachment(UniversalBaseModel):
    created_at: dt.datetime = pydantic.Field()
    """
    Creation timestamp
    """

    file_size: int = pydantic.Field()
    """
    Attachment file size in bytes (up to 5TB)
    """

    id: str = pydantic.Field()
    """
    Comment attachment ID
    """

    media_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    File media type
    """

    name: str = pydantic.Field()
    """
    File name for the attachment
    """

    upload_urls: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Comment attachment upload URLs. Number of URLs returned will vary depending on the file size.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
