# This file was auto-generated by Fern from our API Definition.

import typing

from .boolean_value import BooleanValue
from .date_value import DateValue
from .integer_value import IntegerValue
from .multi_select_value import MultiSelectValue
from .multi_user_value import MultiUserValue
from .number_value import NumberValue
from .select_value import SelectValue
from .single_user_value import SingleUserValue
from .text_value import TextValue

MetadataField = typing.Union[
    DateValue,
    NumberValue,
    IntegerValue,
    SelectValue,
    MultiSelectValue,
    TextValue,
    BooleanValue,
    SingleUserValue,
    MultiUserValue,
]
