# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .asset_common import AssetCommon


class Folder(AssetCommon):
    cover_file_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Cover asset ID
    """

    restricted: bool = pydantic.Field()
    """
    Folder is restricted or not
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
