# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import UniversalBaseModel


class FolderUpdateParamsData(UniversalBaseModel):
    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Folder name
    """

    restricted: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Folder is restricted or not.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
