# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.date_definition_params import DateDefinitionParams
from ...types.long_text_definition_params import LongTextDefinitionParams
from ...types.number_definition_params import NumberDefinitionParams
from ...types.rating_definition_params import RatingDefinitionParams
from ...types.select_definition_params import SelectDefinitionParams
from ...types.select_multi_definition_params import SelectMultiDefinitionParams
from ...types.text_definition_params import TextDefinitionParams
from ...types.toggle_definition_params import ToggleDefinitionParams
from ...types.user_multi_definition_params import UserMultiDefinitionParams
from ...types.user_single_definition_params import UserSingleDefinitionParams

CreateFieldDefinitionParamsData = typing.Union[
    DateDefinitionParams,
    LongTextDefinitionParams,
    NumberDefinitionParams,
    RatingDefinitionParams,
    SelectDefinitionParams,
    SelectMultiDefinitionParams,
    TextDefinitionParams,
    ToggleDefinitionParams,
    UserMultiDefinitionParams,
    UserSingleDefinitionParams,
]
