# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .field_value_common import FieldValueCommon
from .select_option import SelectOption


class SelectValue(FieldValueCommon):
    field_options: typing.Optional[typing.List[SelectOption]] = None
    value: typing.Optional[typing.List[SelectOption]] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
