# This file was auto-generated by Fern from our API Definition.

import typing

WorkspacesIndexRequestSort = typing.Union[
    typing.Literal["name_asc", "created_at_asc", "name_desc", "created_at_desc"], typing.Any
]
