# This file was auto-generated by Fern from our API Definition.

import typing

TextReviewAnnotationUpdateTextReviewAnnotationType = typing.Union[
    typing.Literal["highlight", "insert", "remove", "replace"], typing.Any
]
